/*
 * MZViewer - A viewer for MZData format Mass Spectra
 * Copyright (c) 2005 Simon Andrews

 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
package uk.ac.bbsrc.babraham.mzdata;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.print.PrinterException;
import java.awt.print.PrinterJob;
import java.io.File;

import javax.swing.*;
import javax.swing.filechooser.FileFilter;

import uk.ac.bbsrc.babraham.mzdata.displays.GenericMSDisplay;
import uk.ac.bbsrc.babraham.mzdata.displays.LoadProgressDisplay;
import uk.ac.bbsrc.babraham.mzdata.displays.MZMenu;
import uk.ac.bbsrc.babraham.mzdata.parser.MZDataReader;

public class MZViewer extends JFrame {
	
	private GenericMSDisplay display = null;
	private MZDataReader reader;
	private Container c;
	private String lastFolderUsed = null;

	public final String VERSION = "0.4 final";
	
	public MZViewer () {
		
		reader = new MZDataReader();
		c = getContentPane();
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setTitle("MZData Mass Spectrum Viewer");
		setJMenuBar(new MZMenu(this));
		c.setLayout(new BorderLayout());
		setSize(800,600);
		setLocationRelativeTo(null);
		setVisible(true);
	}
	
	public void openNewFile () {
		JFileChooser chooser = new JFileChooser(lastFolderUsed);
  		chooser.setFileFilter(new FileFilter() {
            public boolean accept(File f) {
                if (f.isDirectory()) {
                    return true;
                }
                if (f.getName().toLowerCase().endsWith(".xml")){
		    		return true;
                }
                else if (f.getName().toLowerCase().endsWith(".mzxml")) {
                    return true;
                }
                else if (f.getName().toLowerCase().endsWith(".mzdata")) {
                    return true;
                }
                return false;
            }

			public String getDescription() {
				return "MZData files";
			}
  		});
		int result = chooser.showOpenDialog(this);
		if (result == JFileChooser.CANCEL_OPTION) return;
		
		lastFolderUsed = chooser.getSelectedFile().getAbsolutePath();
		MZCollection collection = null;
		try {
			LoadProgressDisplay progress = new LoadProgressDisplay(this);
			reader.addLoadProgressListener(progress);

			collection = reader.readMZFile(chooser.getSelectedFile().getAbsolutePath());
			progress.setVisible(true);
		}
		catch (Exception e) {
			JOptionPane.showMessageDialog(this,"Error reading file: "+e.getMessage(),"Error",JOptionPane.ERROR_MESSAGE);
			e.printStackTrace();
			return;
		}

		if (display != null) {
			c.remove(display);
		}
	    display = new GenericMSDisplay(collection);
	    c.add(display,BorderLayout.CENTER);
	    this.validate();
	}
	
	public void print () {
	    PrinterJob job = PrinterJob.getPrinterJob();
	    job.setPrintable(display);
	    if (job.printDialog()) {
	        try {
	            job.print();
	        }
	        catch (PrinterException pe) {
	            JOptionPane.showMessageDialog(this,"Error Whilst Printing: "+pe.getMessage(),"Error", JOptionPane.ERROR_MESSAGE);
	        }
	    }

	}
	
	public static void main(String[] args) {
	    try {
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		}
		catch (Exception e) {
		    System.err.println("Failed to set LAF "+e);
			// If it doesn't work - well who cares anyway...
		}

		new MZViewer();
	}
	
}
